@@ -18,11 +18,13 @@ class BoardRules():
         piece: The piece being moved
     """
 
-    def __init__(self, move):
+    def __init__(self, move, debug=False, check_checking=False):
         """Init."""
         self.move = move
         self.valid = True
         self.piece = self.move.origin_sq.occupant
+        self.debug = debug
+        self.check_checking = check_checking
         self.apply()
 
     def apply(self):
@@ -32,11 +34,12 @@ class BoardRules():
         if not isinstance(self.piece, pieces.Knight):
             self.__blocking_pieces()
         if self.move.is_castling():
-            self.__castling()
+            if not self.check_checking:
+                self.__castling()
         else:
             if self.move.is_capturing():
                 self.__capturing()
-            self.__self_checking()
+            # self.__self_checking()
 
     def __capturing(self):
         """Check if this is a capturing move."""
@@ -46,18 +49,17 @@ class BoardRules():
 
     def __pawn_rules(self):
         """Rules to apply to pawns only."""
-        if self.move.horizontal == 1:
-            # If we're going horizontal, are we at least capturing?
-            if not self.move.destination_sq.occupant:
-                d_letter = self.move.destination[0]
-                o_number = int(self.move.origin[1])
-                # If not, is it at least en passant?
-                pass_sq = self.move.board.squares[d_letter][o_number]
-                if isinstance(pass_sq.occupant, pieces.Pawn):
-                    self.enpassant = pass_sq
-                else:
-                    self.valid = False
-        elif self.move.vertical > 0:
+        if (self.move.horizontal == 1
+           or self.move.horizontal == -1):
+            # Exit early if we're capturing horizontally
+            if self.move.destination_sq.occupant:
+                return True
+
+            if not self.move.enpassant:
+                self.valid = False
+
+        elif (self.move.vertical > 0
+                or self.move.vertical < 0):
             if self.move.destination_sq.occupant:
                 self.valid = False
 
@@ -70,8 +72,9 @@ class BoardRules():
     def __self_checking(self):
         """Check if the move puts the player itself in check."""
         newboard = self.move.board.new_board(self.move)
-        if newboard.is_check() == self.piece.color:
-            self.valid = False
+        if self.valid:
+            if newboard.is_check(color=self.piece.color) == self.piece.color:
+                self.valid = False
 
     def __castling(self):
         """Apply rules specific to castling."""
