@@ -12,6 +12,8 @@ Example:
 """
 
 from nerdchess import pieces
+from nerdchess import game_event
+from nerdchess.config import colors
 from nerdchess.board import Board
 from nerdchess.boardmove import BoardMove
 
@@ -19,6 +21,9 @@ from nerdchess.boardmove import BoardMove
 class ChessGame():
     """Creates a new chessgame with players, pieces, and sets up the board.
 
+    Main interface for nerdchess.
+    Args and returns for public functions should inherit the GameEvent type.
+
     Parameters:
         name_1(Player): Player 1
         name_2(Player): Player 2
@@ -66,13 +71,13 @@ class ChessGame():
         move = BoardMove(self.board, move)
 
         if not player.turn:
-            return False
+            return game_event.MoveEvent(False)
 
         if move.origin_sq.occupant:
             if move.origin_sq.occupant.color != player.color:
-                return False
+                return game_event.MoveEvent(False)
         else:
-            return False
+            return game_event.MoveEvent(False)
 
         result = move.process()
         if result:
@@ -80,9 +85,32 @@ class ChessGame():
             if result.is_checkmate():
                 self.over = True
             self.board = result
-            self.board.squares[move.text[2]][int(
-                move.text[3])].occupant.last_move = move
             self.pass_turn()
-            return True
+            return game_event.MoveEvent(True, promotion=move.promotion)
         else:
-            return False
+            return game_event.MoveEvent(False)
+
+    def promote(self, pawn, target):
+        """Promote a pawn.
+
+        Parameters:
+            pawn: The pawn object to promote
+            target: The target nerdchess.Piece object
+
+        returns:
+            PromotionEvent: Result object containing event information
+        """
+        if not isinstance(pawn, pieces.Pawn):
+            return game_event.PromotionEvent(False)
+
+        if pawn.color == colors.WHITE:
+            if pawn.last_move.text[3] == '8':
+                return game_event.MoveEvent(self.board.promote(pawn, target))
+            else:
+                return game_event.MoveEvent(False)
+        else:
+            if pawn.last_move.text[3] == '1':
+                return game_event.MoveEvent(self.board.promote(pawn, target))
+            else:
+                return game_event.MoveEvent(False)
+
