@@ -180,6 +180,8 @@ class TestBoardRules():
     @pytest.mark.parametrize("move,expected,side,color", [
         # Queenside castle for white with no checks etc.
         ('e1a1', True, 'queenside', colors.WHITE),
+        # Kingside castle for white with no checks etc.
+        ('e1h1', True, 'kingside', colors.WHITE),
         # Same as above but differnt notation
         ('e1b1', True, 'queenside', colors.WHITE),
         # Black kingside no checks etc.
@@ -197,8 +199,9 @@ class TestBoardRules():
         board_fixt.place_piece(pieces.King(colors.BLACK), 'e8')
         board_fixt.place_piece(pieces.Rook(colors.BLACK), 'a8')
         board_fixt.place_piece(pieces.Rook(colors.BLACK), 'h8')
-        board_fixt.place_piece(pieces.Bishop(colors.BLACK), 'h3')
         board_fixt.place_piece(pieces.Bishop(colors.WHITE), 'f5')
+        if color == colors.WHITE and not expected and side == 'kingside':
+            board_fixt.place_piece(pieces.Bishop(colors.BLACK), 'h3')
 
         boardmove = BoardMove(board_fixt.board, move)
 
@@ -240,3 +243,17 @@ class TestBoardRules():
         result = boardmove.process()
 
         assert result == expected
+
+    @pytest.mark.parametrize("move,position,color,expected", [
+        ('e7e8', 'e7', colors.WHITE, True),
+        ('e6e7', 'e6', colors.WHITE, False),
+        ('e2e1', 'e2', colors.BLACK, True),
+        ('e3e2', 'e3', colors.BLACK, False),
+    ])
+    def test_promotion(self, board_fixt, move, position, color, expected):
+        """Test if promotion is properly detected."""
+        board_fixt.place_piece(pieces.Pawn(color), position)
+
+        boardmove = BoardMove(board_fixt.board, move)
+
+        assert boardmove.promotion == expected
